from django.apps import AppConfig
from django.db.models.signals import post_migrate


class SmartminConfig(AppConfig):
    name = "smartmin"

    def ready(self):
        from .perms import sync_permissions

        post_migrate.connect(sync_permissions)



from django.conf import settings
from django.utils import timezone


class TimezoneMiddleware:
    def __init__(self, get_response=None):
        self.get_response = get_response

    def __call__(self, request):
        response = self.get_response(request)

        user_tz = getattr(settings, "USER_TIME_ZONE", None)

        if user_tz:
            timezone.activate(user_tz)

        return response
